#include "radar_boardCaptureOnly_priv.h"
#include <src/include/chains_common.h>
#include <src/rtos/iss/include/iss_sensors.h>
#include <src/rtos/iss/include/iss_utils.h>
#include <src/rtos/iss/include/app_util_iss.h>
#include <include/common/chains_radar.h>
#include <ti/drv/vps/include/vps.h>
#include <ti/drv/vps/include/vps_capture.h>

/**
 *******************************************************************************
 *
 *  \brief  radar_boardCaptureOnlyAppObj
 *
 *        This structure contains all the LinksId's and create Params.
 *        The same is passed to all create, start, stop functions.
 *
 *******************************************************************************
*/
typedef struct {
	radar_boardCaptureOnlyObj 	ucObj; 

	Chains_Ctrl		*chainsCfg;  

	ChainsCommon_Ar12xxConfigOut	ar12xxCfg; 
} radar_boardCaptureOnlyAppObj; 

char radar_boardCaptureOnly_runTimeMenu[] = {
	"\r\n "
	"\r\n ===================="
	"\r\n Chains Run-time Menu"
	"\r\n ===================="
	"\r\n "
	"\r\n 0: Stop Chain"
	"\r\n "
	"\r\n p: Print Performance Statistics "
	"\r\n "
	"\r\n Enter Choice: "
	"\r\n "
}; 

// Void radar_boardCaptureOnly_setMuxes(
// 	radar_boardCaptureOnlyAppObj *pObj)
// {
// 	ChainsPlatform_SetPinMux(pObj->chainsCfg->sensorName); 
// 	ChainsBoard_SetBoardMux(pObj->chainsCfg->sensorName); 
// }

/**
 *******************************************************************************
 *
 * \brief   Set link Parameters
 *
 *          It is called in Create function of the auto generated use-case file.
 *
 * \param pUcObj    [IN] Auto-generated usecase object
 * \param appObj    [IN] Application specific object
 *
 *******************************************************************************
*/
Void radar_boardCaptureOnly_SetAppPrms(
	radar_boardCaptureOnlyObj *pUcObj, Void *appObj)
{
	radar_boardCaptureOnlyAppObj *pObj
		= (radar_boardCaptureOnlyAppObj*) appObj; 

	// strncpy(pObj->appSensInfo.sensorName, pObj->chainsCfg->sensorName,
 //        ISS_SENSORS_MAX_NAME);
	// pObj->appSensInfo.numCh = 1;
	// pObj->appSensInfo.numCSI2Inst = 1;
	// appCreateISSSensor(&pObj->appSensInfo);

 //    appInitIssCaptParams(&pObj->appSensInfo, pUcObj->IssCaptureLinkID,
 //    &pUcObj->IssCapturePrm);	

 //    appStartIssSensorSerDes(&pObj->appSensInfo);

    Chains_ar12xxGetSampleConfig(&pObj->ar12xxCfg, 0U); 
	ChainsCommon_ar12xxConfig(&pObj->ar12xxCfg);
	ChainsCommon_ar12xxSetIssCaptureParams(&pUcObj->IssCapturePrm, &pObj->ar12xxCfg);

	ChainsCommon_networkTxSetMode(&pUcObj->NetworkTxPrm);
	return; 
}

/**
 *******************************************************************************
 *
 * \brief   Start the capture display Links
 *
 *          Function sends a control command to capture and display link to
 *          to Start all the required links . Links are started in reverce
 *          order as information of next link is required to connect.
 *          System_linkStart is called with LinkId to start the links.
 *
 * \param   pObj  [IN] radar_boardCaptureOnlyAppObj
 *
 * \return  SYSTEM_LINK_STATUS_SOK on success
 *
 *******************************************************************************
*/
Void radar_boardCaptureOnly_StartApp(radar_boardCaptureOnlyAppObj *pObj)
{
	Chains_memPrintHeapStatus(); 

	// radar_boardCaptureOnly_setMuxes(pObj); 

	radar_boardCaptureOnly_Start(&pObj->ucObj); 

	ChainsCommon_ar12xxStart(); 

	Chains_prfLoadCalcEnable(TRUE, FALSE, FALSE); 
}

/**
 *******************************************************************************
 *
 * \brief   Delete the capture display Links
 *
 *          Function sends a control command to capture and display link to
 *          to delete all the prior created links
 *          System_linkDelete is called with LinkId to delete the links.
 *
 * \param   pObj   [IN]   radar_boardCaptureOnlyAppObj
 *
 *******************************************************************************
*/
Void radar_boardCaptureOnly_StopAndDeleteApp(radar_boardCaptureOnlyAppObj *pObj)
{
	radar_boardCaptureOnly_Stop(&pObj->ucObj); 
	radar_boardCaptureOnly_Delete(&pObj->ucObj); 

	ChainsCommon_ar12xxStop(&pObj->ar12xxCfg); 

	// appStopISSSensor(&pObj->appSensInfo);

 //    appDeleteISSSensor(&pObj->appSensInfo);

	Chains_prfLoadCalcEnable(FALSE, TRUE, TRUE); 
}

/**
 *******************************************************************************
 *
 * \brief   Radar Board Capture usecase function
 *
 *          This functions executes the create, start functions
 *
 *          Further in a while loop displays run time menu and waits
 *          for user inputs to print the statistics or to end the demo.
 *
 *          Once the user inputs end of demo stop and delete
 *          functions are executed.
 *
 * \param   chainsCfg       [IN]   Chains_Ctrl
 *
 *******************************************************************************
*/
Void radar_boardCaptureOnly(Chains_Ctrl *chainsCfg)
{
	char ch; 
	UInt32 done = FALSE; 
	radar_boardCaptureOnlyAppObj chainsObj; 

	Vps_printf("Entered radar_boardCaptureOnly \n"); 

	chainsObj.chainsCfg = chainsCfg; 

	radar_boardCaptureOnly_Create(&chainsObj.ucObj, &chainsObj); 
	// ChainsCommon_SetIssCaptureErrorHandlingCb(chainsObj.ucObj.IssCaptureLinkID);

	radar_boardCaptureOnly_StartApp(&chainsObj); 

	while(!done)
	{
		Vps_printf(radar_boardCaptureOnly_runTimeMenu); 

		ch = Chains_readChar(); 

		switch(ch)
		{
			case '0':
				done = TRUE; 
				break; 
			case 'p':
			case 'P':
				ChainsCommon_PrintStatistics(); 
				radar_boardCaptureOnly_printStatistics(&chainsObj.ucObj); 
				break; 
			default:
				Vps_printf("\nUnsupported option '%c'. Please try again\n", ch); 
				break; 
		}
	}
	radar_boardCaptureOnly_StopAndDeleteApp(&chainsObj); 
}
